// SPDX-FileCopyrightText: Matteo Settenvini <matteo.settenvini@montecristosoftware.eu>
// SPDX-License-Identifier: GPL-3.0-or-later

#![allow(non_upper_case_globals)]
#![allow(non_camel_case_types)]
#![allow(non_snake_case)]

mod gethostbyaddr;
mod gethostbyname;
mod helpers;
pub mod nss_api;
mod nss_bindings;
mod policy_checker;

use std::str::FromStr;

struct LevelFilter(log::LevelFilter);

impl FromStr for LevelFilter {
    type Err = ();

    fn from_str(s: &str) -> Result<Self, Self::Err> {
        let lv = match s.to_lowercase().as_str() {
            "off" => log::LevelFilter::Off,
            "error" => log::LevelFilter::Error,
            "warn" => log::LevelFilter::Warn,
            "info" => log::LevelFilter::Info,
            "debug" => log::LevelFilter::Debug,
            "trace" => log::LevelFilter::Trace,
            _ => return Err(()),
        };
        Ok(Self(lv))
    }
}

ld_preload::ld_preload_init! {
    {
        let level = std::env::var("NSS_MALCONTENT_LOG")
            .ok()
            .and_then(|level| { LevelFilter::from_str(&level).ok() })
            .map(|x| x.0)
            .unwrap_or(log::LevelFilter::Warn);

        let _ = syslog::init(syslog::Facility::LOG_AUTHPRIV, level, Some("nss_malcontent"));
    }
}
